<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="es">
<context>
    <name>LxImage::Application</name>
    <message>
        <location filename="../application.cpp" line="94"/>
        <source>Take a screenshot</source>
        <translation>Capturar la pantalla</translation>
    </message>
    <message>
        <location filename="../application.cpp" line="101"/>
        <source>Take a screenshot to folder without gui</source>
        <translation>Hacer una captura de pantalla a una carpeta sin interfaz gráfica</translation>
    </message>
    <message>
        <location filename="../application.cpp" line="105"/>
        <source>[FILE1, FILE2,...]</source>
        <translation>[ARCHIVO1, ARCHIVO2, …]</translation>
    </message>
</context>
<context>
    <name>LxImage::ImageShackUpload</name>
    <message>
        <location filename="../upload/imageshackupload.cpp" line="50"/>
        <source>unknown error response</source>
        <translation>respuesta de error desconocido</translation>
    </message>
</context>
<context>
    <name>LxImage::ImgBBUpload</name>
    <message>
        <location filename="../upload/imgbbupload.cpp" line="44"/>
        <source>unknown error response</source>
        <translation>respuesta de error desconocido</translation>
    </message>
</context>
<context>
    <name>LxImage::ImgurUpload</name>
    <message>
        <location filename="../upload/imgurupload.cpp" line="47"/>
        <source>unknown error response</source>
        <translation>respuesta de error desconocido</translation>
    </message>
</context>
<context>
    <name>LxImage::MainWindow</name>
    <message>
        <location filename="../mainwindow.cpp" line="180"/>
        <source>About</source>
        <translation>Acerca de</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="181"/>
        <source>LXImage-Qt - a simple and fast image viewer

Copyright (C) 2013
LXQt Project: https://lxqt.org/

Authors:
Hong Jen Yee (PCMan) &lt;pcman.tw@gmail.com&gt;</source>
        <translation>LXImage-Qt - un visor de imágenes sencillo y rápido

Copyright (C) 2013
Proyecto LXQt: https://lxqt.org/

Autores:
Hong Jen Yee (PCMan) &lt;pcman.tw@gmail.com&gt;</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="320"/>
        <source>Open File</source>
        <translation>Abrir un archivo</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="321"/>
        <location filename="../mainwindow.cpp" line="356"/>
        <source>Image files (%1)</source>
        <translation>Imágenes (%1)</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="334"/>
        <source>Open directory</source>
        <translation>Abrir un directorio</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="355"/>
        <source>Save File</source>
        <translation>Guardar el archivo</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="635"/>
        <source>[*]%1 (Loading...) - Image Viewer</source>
        <translation>[*]%1 (Cargando...) - Visor de imágenes</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="640"/>
        <source>[*]%1 (Failed to Load) - Image Viewer</source>
        <translation>[*]%1 (La carga ha fallado) - Visor de imágenes</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="644"/>
        <source>[*]%1 (%2x%3) - Image Viewer</source>
        <translation>[*]%1 (%2x%3) - Visor de imágenes</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="680"/>
        <source>[*]Image Viewer</source>
        <translation>[*]Visor de imágenes</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="992"/>
        <source>Thumbnails</source>
        <translation>Miniaturas</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1042"/>
        <source>EXIF Data</source>
        <translation>Datos EXIF</translation>
    </message>
</context>
<context>
    <name>LxImage::MruMenu</name>
    <message>
        <location filename="../mrumenu.cpp" line="45"/>
        <source>&amp;Clear</source>
        <translation>Limpiar</translation>
    </message>
</context>
<context>
    <name>LxImage::UploadDialog</name>
    <message>
        <location filename="../upload/uploaddialog.cpp" line="52"/>
        <source>Imgur</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../upload/uploaddialog.cpp" line="53"/>
        <source>ImgBB</source>
        <translation>ImgBB</translation>
    </message>
    <message>
        <location filename="../upload/uploaddialog.cpp" line="54"/>
        <source>ImageShack</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../upload/uploaddialog.cpp" line="137"/>
        <source>Start</source>
        <translation>Empezar</translation>
    </message>
    <message>
        <location filename="../upload/uploaddialog.cpp" line="140"/>
        <source>Stop</source>
        <translation>Detener</translation>
    </message>
    <message>
        <location filename="../upload/uploaddialog.cpp" line="143"/>
        <source>Close</source>
        <translation>Cerrar</translation>
    </message>
    <message>
        <location filename="../upload/uploaddialog.cpp" line="150"/>
        <source>Error</source>
        <translation>Error</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../mainwindow.ui" line="14"/>
        <source>Image Viewer</source>
        <translation>Visor de imágenes</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="177"/>
        <location filename="../mainwindow.ui" line="617"/>
        <source>Annotations Toolbar</source>
        <translation>Barra de herramientas de anotaciones</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="197"/>
        <source>&amp;About</source>
        <translation>&amp;Acerca de</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="209"/>
        <source>Ctrl+O</source>
        <translation>Ctrl+O</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="230"/>
        <source>&amp;Save</source>
        <translation>&amp;Guardar</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="233"/>
        <source>Ctrl+S</source>
        <translation>Ctrl+S</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="242"/>
        <source>Save &amp;As</source>
        <translation>G&amp;uardar como…</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="245"/>
        <source>Ctrl+A</source>
        <translation>Ctrl+A</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="254"/>
        <source>&amp;Close</source>
        <translation>&amp;Cerrar</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="257"/>
        <source>Ctrl+W</source>
        <translation>Ctrl+W</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="266"/>
        <source>Zoom &amp;In</source>
        <translation>&amp;Ampliar</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="278"/>
        <source>Zoom &amp;Out</source>
        <translation>&amp;Reducir</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="281"/>
        <source>Ctrl+-</source>
        <translation>Ctrl+−</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="290"/>
        <source>&amp;Copy to Clipboard</source>
        <translation>&amp;Copiar al portapapeles</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="299"/>
        <location filename="../mainwindow.ui" line="302"/>
        <source>Next File</source>
        <translation>Archivo siguiente</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="314"/>
        <location filename="../mainwindow.ui" line="317"/>
        <source>Previous File</source>
        <translation>Archivo anterior</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="269"/>
        <source>Ctrl+=</source>
        <translation>Ctrl+=</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="67"/>
        <source>&amp;Recently Opened Files</source>
        <translation>Archivos abiertos &amp;recientemente</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="206"/>
        <source>&amp;Open…</source>
        <translation>A&amp;brir…</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="218"/>
        <source>&amp;Reload File</source>
        <translation>&amp;Recargar el archivo</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="221"/>
        <source>Ctrl+R</source>
        <translation>Ctrl+R</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="305"/>
        <source>PgDown</source>
        <translation>Av Pág</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="320"/>
        <source>PgUp</source>
        <translation>Re Pág</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="329"/>
        <source>Original Size</source>
        <translation>Tamaño original</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="332"/>
        <source>Ctrl+0</source>
        <translation>Ctrl+0</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="341"/>
        <source>&amp;Fit</source>
        <translation>A&amp;justar</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="350"/>
        <source>&amp;Rotate Clockwise</source>
        <translation>&amp;Girar a la derecha</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="353"/>
        <source>R</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="362"/>
        <source>Rotate &amp;Counterclockwise</source>
        <translation>G&amp;irar a la izquierda</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="365"/>
        <source>L</source>
        <translation>L</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="370"/>
        <source>P&amp;references</source>
        <translation>P&amp;referencias</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="375"/>
        <source>&amp;Print</source>
        <translation>Im&amp;primir</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="378"/>
        <source>Ctrl+P</source>
        <translation>Ctrl+P</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="387"/>
        <source>First File</source>
        <translation>Primer archivo</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="390"/>
        <source>Home</source>
        <translation>Inicio</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="399"/>
        <source>Last File</source>
        <translation>Último archivo</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="402"/>
        <source>End</source>
        <translation>Fin</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="411"/>
        <source>&amp;New Window</source>
        <translation>&amp;Nueva ventana</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="414"/>
        <source>Ctrl+N</source>
        <translation>Ctrl+N</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="419"/>
        <source>Flip &amp;Horizontally</source>
        <translation>Voltear &amp;horizontalmente</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="422"/>
        <source>H</source>
        <translation>H</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="431"/>
        <source>Capture Screenshot</source>
        <translation>Capturar la pantalla</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="439"/>
        <source>F&amp;ull Screen</source>
        <translation>Pa&amp;ntalla completa</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="442"/>
        <source>F11</source>
        <translation>F11</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="447"/>
        <source>Flip &amp;Vertically</source>
        <translation>Voltear &amp;verticalmente</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="450"/>
        <source>V</source>
        <translation>V</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="459"/>
        <source>&amp;Paste from Clipboard</source>
        <translation>&amp;Pegar del portapapeles</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="471"/>
        <source>&amp;Slide Show</source>
        <translation>Pa&amp;se de diapositivas</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="480"/>
        <source>&amp;Delete</source>
        <translation>&amp;Eliminar</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="483"/>
        <source>Del</source>
        <translation>Supr</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="491"/>
        <source>Show Thumbnails</source>
        <translation>Mostrar miniaturas</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="494"/>
        <source>T</source>
        <translation>T</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="499"/>
        <source>File Properties</source>
        <translation>Propiedades del archivo</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="508"/>
        <source>Open &amp;Directory</source>
        <translation>Abrir un &amp;directorio</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="511"/>
        <source>Ctrl+D</source>
        <translation>Ctrl+D</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="520"/>
        <source>Upload</source>
        <translation>Subir</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="523"/>
        <source>Upload the image</source>
        <translation>Subir la imagen</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="531"/>
        <source>Show EXIF Data</source>
        <translation>Mostrar los datos EXIF</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="543"/>
        <source>No Tool</source>
        <translation>Ninguna herramienta</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="546"/>
        <source>Deselect all drawing tools</source>
        <translation>Deselecionar todas las herramientas de dibujo</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="558"/>
        <source>Draw Arrow</source>
        <translation>Dibujar flecha</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="561"/>
        <source>Draw an arrow</source>
        <translation>Dibuja una flecha</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="573"/>
        <source>Draw Rectangle</source>
        <translation>Dibujar rectángulo</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="576"/>
        <source>Draw a hollow rectangle</source>
        <translation>Dibuja un rectángulo hueco</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="588"/>
        <source>Draw Circle</source>
        <translation>Dibujar circunferencia</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="591"/>
        <source>Draw a hollow circle</source>
        <translation>Dibuja un círculo hueco</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="603"/>
        <source>Draw Number</source>
        <translation>Dibujar número</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="606"/>
        <source>Draw incrementing numbers</source>
        <translation>Dibuja números crecientes</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="614"/>
        <source>&amp;Annotations Toolbar</source>
        <translation>&amp;Barra de herramientas de anotaciones</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="625"/>
        <location filename="../mainwindow.ui" line="628"/>
        <source>Show Outline</source>
        <translation>Mostrar el contorno</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="631"/>
        <source>O</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="63"/>
        <source>&amp;File</source>
        <translation>&amp;Archivo</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="87"/>
        <source>&amp;Help</source>
        <translation>Ay&amp;uda</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="93"/>
        <source>Go</source>
        <translation>Ir</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="102"/>
        <source>&amp;View</source>
        <translation>&amp;Ver</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="120"/>
        <source>&amp;Edit</source>
        <translation>&amp;Editar</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="142"/>
        <source>Toolbar</source>
        <translation>Barra de herramientas</translation>
    </message>
</context>
<context>
    <name>PreferencesDialog</name>
    <message>
        <location filename="../preferencesdialog.ui" line="14"/>
        <source>Preferences</source>
        <translation>Preferencias</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="33"/>
        <source>Icon theme:</source>
        <translation>Tema de iconos:</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="43"/>
        <source>Normal background color:</source>
        <translation>Color de fondo normal:</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="50"/>
        <source>Fullscreen background color:</source>
        <translation>Color de fondo a pantalla completa:</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="71"/>
        <source>Slide show interval (seconds):</source>
        <translation>Intervalo de presentación de diapositivas (segundos):</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="85"/>
        <source>Show image outline by default</source>
        <translation>Mostrar el contorno de la imagen por defecto</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="92"/>
        <source>Show annotations toolbar by default</source>
        <translation>Mostrar la barra de anotaciones por defecto</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="24"/>
        <source>General</source>
        <translation>General</translation>
    </message>
</context>
<context>
    <name>ScreenshotDialog</name>
    <message>
        <location filename="../screenshotdialog.ui" line="14"/>
        <source>Screenshot</source>
        <translation>Captura de pantalla</translation>
    </message>
    <message>
        <location filename="../screenshotdialog.ui" line="27"/>
        <source>Take a screenshot</source>
        <translation>Capturar la pantalla</translation>
    </message>
    <message>
        <location filename="../screenshotdialog.ui" line="34"/>
        <source>Region</source>
        <translation>Región</translation>
    </message>
    <message>
        <location filename="../screenshotdialog.ui" line="40"/>
        <source>Whole screen</source>
        <translation>Toda la pantalla</translation>
    </message>
    <message>
        <location filename="../screenshotdialog.ui" line="50"/>
        <source>Current window only</source>
        <translation>Solo la ventana actual</translation>
    </message>
    <message>
        <location filename="../screenshotdialog.ui" line="57"/>
        <source>Capture an area of the screen</source>
        <translation>Capturar un área de la pantalla</translation>
    </message>
    <message>
        <location filename="../screenshotdialog.ui" line="67"/>
        <source>Include mouse cursor</source>
        <translation>Incluir el puntero del ratón</translation>
    </message>
    <message>
        <location filename="../screenshotdialog.ui" line="74"/>
        <source> seconds</source>
        <translation> segundos</translation>
    </message>
    <message>
        <location filename="../screenshotdialog.ui" line="91"/>
        <source>Delay:</source>
        <translation>Retardo:</translation>
    </message>
    <message>
        <location filename="../screenshotdialog.ui" line="101"/>
        <source>Include window title and frame</source>
        <translation>Incluir el marco y el título de la ventana</translation>
    </message>
</context>
<context>
    <name>UploadDialog</name>
    <message>
        <location filename="../upload/uploaddialog.ui" line="14"/>
        <source>Upload</source>
        <translation>Subir</translation>
    </message>
    <message>
        <location filename="../upload/uploaddialog.ui" line="39"/>
        <source>Copy</source>
        <translation>Copiar</translation>
    </message>
</context>
</TS>
